#
# Regular cron jobs for the fahrplan package
#
#0 4	* * *	root	fahrplan_maintenance
